@@ -2,7 +2,7 @@
 
 import sys
 sys.path.append('../')
-from linux.shared_scripts import filechecker, folderchecker, sizechecker
+from linux.shared_scripts.modules import filechecker, folderchecker, sizechecker
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 def taskchecker():
     filechecker("/tmp/services")
